// ----------------------------------------------------------------------------------------
// 
// umFishLoad.h                                                      Ulrich Mller  25.1.00
//                                                                   Procida 400NT VC++ 6.0
// 
// Basisfunktionen fr die fischertechnik Interfaces (seriell und und parallel)
// Dynamisches Laden der umFish.DLL
//
// -----------------------------------------------------------------------------------------

#include <windows.h>

typedef struct {
  HANDLE hCom;
  DWORD PortID;
  DWORD LPTDelay;
  DWORD LPTAnalog;
  DWORD InputStatus;
  DWORD MotorStatus;
} ftDCB;

HINSTANCE umFishLib;

// --- umFish : Funktionsprototypen --------------------------------------------

typedef DWORD (__stdcall *TOpenInterface) (ftDCB *Interface, LPCSTR ComName);
typedef DWORD (__stdcall *TCloseInterface) (ftDCB *Interface);
typedef BOOL  (__stdcall *TGetInput) (ftDCB *Interface, DWORD InputNr);
typedef DWORD (__stdcall *TGetInputs) (ftDCB *Interface);
typedef DWORD (__stdcall *TClearMotors) (ftDCB *Interface);
typedef DWORD (__stdcall *TSetMotors) (ftDCB *Interface, DWORD MotorStatus);
typedef DWORD (__stdcall *TSetLamp) (ftDCB *Interface, DWORD LampNr, DWORD OnOff);
typedef DWORD (__stdcall *TSetMotor) (ftDCB *Interface, DWORD MotorNr, DWORD Direction);
typedef DWORD (__stdcall *TGetAnalog) (ftDCB *Interface, DWORD AnalogNr);
typedef DWORD (__stdcall *TStartDriver) ();
typedef DWORD (__stdcall *TStopDriver) ();

// --- Konstanten ---------------------------------------------------------------

const DWORD ftiAus    = 0;
const DWORD ftiEin    = 1;
const DWORD ftiLinks  = 1;
const DWORD ftiRechts = 2;

const DWORD ftiFehler = 0x0001FFFF;

// --- Funktonen ----------------------------------------------------------------

TOpenInterface   OpenInterface;
TCloseInterface  CloseInterface;
TGetInput        GetInput;
TGetInputs       GetInputs;
TClearMotors     ClearMotors;
TSetMotors       SetMotors;
TSetLamp         SetLamp;
TSetMotor        SetMotor;
TGetAnalog       GetAnalog;
TStartDriver     StartDriver;
TStopDriver      StopDriver;

// --- LadeRoutine LoadFish ------------------------------------------------------

BOOLEAN LoadFish(void)
{
  umFishLib = LoadLibrary("umFish.DLL");
	if(!umFishLib) return FALSE;

	OpenInterface  = (TOpenInterface)  GetProcAddress(umFishLib, "OpenInterface");
	CloseInterface = (TCloseInterface) GetProcAddress(umFishLib, "CloseInterface");
	GetInput       = (TGetInput)       GetProcAddress(umFishLib, "GetInput");
	GetInputs      = (TGetInputs)      GetProcAddress(umFishLib, "GetInputs");
	ClearMotors    = (TClearMotors)    GetProcAddress(umFishLib, "ClearMotors");
	SetMotors      = (TSetMotors)      GetProcAddress(umFishLib, "SetMotors");
	SetLamp        = (TSetLamp)        GetProcAddress(umFishLib, "SetLamp");
	SetMotor       = (TSetMotor)       GetProcAddress(umFishLib, "SetMotor");
	GetAnalog      = (TGetAnalog)      GetProcAddress(umFishLib, "GetAnalog");
	StartDriver    = (TStartDriver)    GetProcAddress(umFishLib, "StartDriver");
	StopDriver     = (TStopDriver)     GetProcAddress(umFishLib, "StopDriver");
	return TRUE;
}

// --- UnloadRoutine FreeFish ----------------------------------------------------

void FreeFish(void)
{
	FreeLibrary(umFishLib);
	umFishLib = NULL;
	return;
}